---
name: Bug Report
about: Create a report to help improve camply
title: ""
labels: "bug"
assignees: "juftin"
---

**Describe the bug**

< A clear and concise description of what the bug is. >

**Original Camply Command (with `--debug`)**

<!-- Replace the below command with your personal camply command, make sure to include the `--debug` -->
<!-- if the output is too long you can attach a text file or omit the `--debug` if needed -->

```console
camply --debug campsites \
    --campground 232338 \
    --start-date 2023-09-09 \
    --end-date 2023-09-32 \
    --nights 3
```

**Expected behavior**
< A clear and concise description of what you expected to happen. >

**Console Output (with `--debug`)**

```
<Add your console output here>
```

**Additional context**

< Add any other context about the problem here. >
